View Source Stargate.Receiver.Acknowledger (stargate v0.3.0)
Defines the Stargate.Receiver.Acknowledger GenStage process
that acts as the final consumer in the receive pipeline to
acknowledge successful processing of messages back to Pulsar
to allow more messages to be sent and for the cluster to
delete messages from the subscription in the case of consumers.
Link to this section Summary
Functions
Starts a Stargate.Receiver.Acknowledger process and links it to
the calling process.
Link to this section Functions
@spec start_link(keyword()) :: GenServer.on_start()
Starts a Stargate.Receiver.Acknowledger process and links it to
the calling process.