View Source Stargate.Receiver.Acknowledger.State (stargate v0.3.0)

Defines the struct used by a Stargate.Receiver.Acknowledger to store its state. Includes the type of the receiver (reader or consumer), the name of the process registry associated with the client supervision tree, the atom key of the receiver socket process within the process registry, and the path parameters of the topic connection (tenant, namespace, topic).