View Source Stargate.Producer.Supervisor (stargate v0.3.0)
Creates and manages a supervisor process for the Stargate producer websocket process and acknowledger process.
Link to this section Summary
Functions
Generates a child specification for creating producer supervisor trees.
Create a Stargate.Producer.Supervisor process and link it
to the calling process.
Link to this section Functions
@spec child_spec(keyword()) :: Supervisor.child_spec()
Generates a child specification for creating producer supervisor trees.
@spec start_link(keyword()) :: GenServer.on_start()
Create a Stargate.Producer.Supervisor process and link it
to the calling process.
Passes the shared and :producer configurations from the
top-level supervisor to the producer and acknowledger and
starts them under a :one_for_one strategy.